@@ -27,8 +27,11 @@
 #include <KDBusService>
 #include <KUrlAuthorized>
 #include <QCommandLineParser>
-#include <QDebug>
 #include <QDir>
+#include <QTreeWidgetItem>
+#include <QMetaType>
+
+Q_DECLARE_METATYPE(const QTreeWidgetItem *)
 
 using namespace KHC;
 
@@ -44,6 +47,10 @@ Application::Application(int& argc, char** argv)
   KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "help:" ) ) );
   KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "info:" ) ) );
   KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "khelpcenter:" ) ), QUrl( QLatin1Literal( "man:" ) ) );
+  KUrlAuthorized::allowUrlAction( QLatin1Literal( "redirect" ), QUrl( QLatin1Literal( "glossentry:" ) ), QUrl( QLatin1Literal( "help:" ) ) );
+
+  // registration of meta types
+  qRegisterMetaType<const QTreeWidgetItem *>();
 }
 
 QCommandLineParser *Application::cmdParser()
@@ -80,9 +87,9 @@ extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
 {
   KHC::Application app(argc, argv);
   KLocalizedString::setApplicationDomain("khelpcenter");
-  KAboutData aboutData( "khelpcenter", i18n("KDE Help Center"),
+  KAboutData aboutData( "khelpcenter", i18n("Help Center"),
                         PROJECT_VERSION,
-                        i18n("The KDE Help Center"),
+                        i18n("Help Center"),
                         KAboutLicense::GPL,
                         i18n("(c) 1999-2011, The KHelpCenter developers") );
 
