@@ -1,8 +1,9 @@
 
 #include "view.h"
 
-#include "formatter.h"
+#include "grantleeformatter.h"
 #include "history.h"
+#include "khc_debug.h"
 
 #include <dom/html_document.h>
 #include <dom/html_head.h>
@@ -12,6 +13,7 @@
 #include <KHTMLSettings>
 #include <KHTMLView>
 #include <KToolBarPopupAction>
+#include <KSharedConfig>
 #include <ki18n_version.h>
 
 #include <QFileInfo>
@@ -19,9 +21,11 @@
 #include <QTextStream>
 #include <QKeyEvent>
 #include <qguiapplication.h>
-#include <QEvent>
 #include <QDir>
 #include <QScrollBar>
+#include <QMenu>
+#include <QStandardPaths>
+#include <QWhatsThis>
 
 using namespace KHC;
 
@@ -32,10 +36,7 @@ View::View( QWidget *parentWidget, QObject *parent, KHTMLPart::GUIProfile prof,
     setJavaEnabled(false);
     setPluginsEnabled(false);
 
-    mFormatter = new Formatter;
-    if ( !mFormatter->readTemplates() ) {
-      qDebug() << "Unable to read Formatter templates.";
-    }
+    mGrantleeFormatter = new GrantleeFormatter;
 
     m_fontScaleStepping = 10;
 
@@ -61,7 +62,7 @@ View::View( QWidget *parentWidget, QObject *parent, KHTMLPart::GUIProfile prof,
 
 View::~View()
 {
-  delete mFormatter;
+  delete mGrantleeFormatter;
 }
 
 void View::copySelectedText()
@@ -276,27 +277,44 @@ bool View::nextPage(bool checkOnly)
 
 bool View::eventFilter( QObject *o, QEvent *e )
 {
-  if ( e->type() != QEvent::KeyPress ||
-       htmlDocument().links().length() == 0 )
+  if ( htmlDocument().links().length() == 0 )
     return KHTMLPart::eventFilter( o, e );
 
-  QKeyEvent *ke = static_cast<QKeyEvent *>( e );
-  if ( ke->modifiers() & Qt::ShiftModifier && ke->key() == Qt::Key_Space ) {
-    // If we're on the first page, it does not make sense to go back.
-    if ( baseURL().path().endsWith( QLatin1String("/index.html") ) )
-      return KHTMLPart::eventFilter( o, e );
+  switch ( e->type() ) {
+    case QEvent::KeyPress: {
+      QKeyEvent *ke = static_cast<QKeyEvent *>( e );
+      if ( ke->modifiers() & Qt::ShiftModifier && ke->key() == Qt::Key_Space ) {
+        // If we're on the first page, it does not make sense to go back.
+        if ( baseURL().path().endsWith( QLatin1String("/index.html") ) )
+          return KHTMLPart::eventFilter( o, e );
 
-    const QScrollBar * const scrollBar = view()->verticalScrollBar();
-    if ( scrollBar->value() == scrollBar->minimum() ) {
-      if (prevPage())
-         return true;
+        const QScrollBar * const scrollBar = view()->verticalScrollBar();
+        if ( scrollBar->value() == scrollBar->minimum() ) {
+          if (prevPage())
+            return true;
+        }
+      } else if ( ke->key() == Qt::Key_Space ) {
+        const QScrollBar * const scrollBar = view()->verticalScrollBar();
+        if ( scrollBar->value() == scrollBar->maximum() ) {
+          if (nextPage())
+            return true;
+        }
+      }
+      break;
     }
-  } else if ( ke->key() == Qt::Key_Space ) {
-    const QScrollBar * const scrollBar = view()->verticalScrollBar();
-    if ( scrollBar->value() == scrollBar->maximum() ) {
-      if (nextPage())
-        return true;
+    case QEvent::WhatsThis: {
+      QHelpEvent *he = static_cast<QHelpEvent *>( e );
+      const QString text = i18n( "<p>Read the topic documentation in this window.<br /><br />Press <b>Space</b>/<b>Shift+Space</b> to scroll, <b>%1</b> to find something, <b>Tab</b>/<b>Shift+Tab</b> to jump, and <b>Enter</b> to follow.</p>",
+                                 actionCollection()->action( "find" )->shortcut().toString( QKeySequence::NativeText ) );
+      QWhatsThis::showText( he->globalPos(), text, qobject_cast<QWidget *>( o ) );
+      e->accept();
+      return true;
     }
+    case QEvent::QueryWhatsThis:
+      e->accept();
+      return true;
+    default:
+      break;
   }
   return KHTMLPart::eventFilter( o, e );
 }
